@@ -123,9 +123,9 @@ class DiegoOperator(PythonOperator):
 
         if isinstance(df, collections.Iterator):
             for part_number, df_part in enumerate(df):
-                self.__execute_df(df=df_part, part_number=part_number, path=temp_file_path)
+                self.__execute_df(df=df_part, part_number=part_number, path=f"s3://{temp_file_path}")
         else:
-            self.__execute_df(df=df, part_number=1, path=temp_file_path)
+            self.__execute_df(df=df, part_number=1, path=f"s3://{temp_file_path}")
 
         response = self.send_file_path_to_diego(temp_file_path)
 
